pub struct CallHierarchyItem {
pub name: String,
pub kind: u32,
pub uri: Option<Uri>,
pub range: Option<Range>,
pub selection_range: Option<Range>,
pub detail: String,
}Expand description
A call hierarchy item (used for both incoming and outgoing calls).
Fields
name: Stringkind: u32uri: Option<Uri>range: Option<Range>selection_range: Option<Range>detail: StringTrait Implementations
Sourceimpl Clone for CallHierarchyItem
impl Clone for CallHierarchyItem
Sourcefn clone(&self) -> CallHierarchyItem
fn clone(&self) -> CallHierarchyItem
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CallHierarchyItem
impl Debug for CallHierarchyItem
Sourceimpl Default for CallHierarchyItem
impl Default for CallHierarchyItem
Sourceimpl Hash for CallHierarchyItem
impl Hash for CallHierarchyItem
Sourceimpl Message for CallHierarchyItem
impl Message for CallHierarchyItem
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for CallHierarchyItem
impl PartialEq for CallHierarchyItem
Sourcefn eq(&self, other: &CallHierarchyItem) -> bool
fn eq(&self, other: &CallHierarchyItem) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for CallHierarchyItem
impl StructuralPartialEq for CallHierarchyItem