pub struct ProvideInlayHintsRequest {
pub uri: Option<Uri>,
pub range: Option<Range>,
pub provider_handle: u32,
}Expand description
Request for inlay hints.
Fields
uri: Option<Uri>range: Option<Range>provider_handle: u32Trait Implementations
Sourceimpl Clone for ProvideInlayHintsRequest
impl Clone for ProvideInlayHintsRequest
Sourcefn clone(&self) -> ProvideInlayHintsRequest
fn clone(&self) -> ProvideInlayHintsRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProvideInlayHintsRequest
impl Debug for ProvideInlayHintsRequest
Sourceimpl Default for ProvideInlayHintsRequest
impl Default for ProvideInlayHintsRequest
Sourceimpl Hash for ProvideInlayHintsRequest
impl Hash for ProvideInlayHintsRequest
Sourceimpl Message for ProvideInlayHintsRequest
impl Message for ProvideInlayHintsRequest
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for ProvideInlayHintsRequest
impl PartialEq for ProvideInlayHintsRequest
Sourcefn eq(&self, other: &ProvideInlayHintsRequest) -> bool
fn eq(&self, other: &ProvideInlayHintsRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for ProvideInlayHintsRequest
impl StructuralPartialEq for ProvideInlayHintsRequest