pub struct ProvideSignatureHelpRequest {
pub uri: Option<Uri>,
pub position: Option<Position>,
pub provider_handle: u32,
}Expand description
Request for signature help.
Fields
uri: Option<Uri>position: Option<Position>provider_handle: u32Trait Implementations
Sourceimpl Clone for ProvideSignatureHelpRequest
impl Clone for ProvideSignatureHelpRequest
Sourcefn clone(&self) -> ProvideSignatureHelpRequest
fn clone(&self) -> ProvideSignatureHelpRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProvideSignatureHelpRequest
impl Debug for ProvideSignatureHelpRequest
Sourceimpl Hash for ProvideSignatureHelpRequest
impl Hash for ProvideSignatureHelpRequest
Sourceimpl Message for ProvideSignatureHelpRequest
impl Message for ProvideSignatureHelpRequest
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for ProvideSignatureHelpRequest
impl PartialEq for ProvideSignatureHelpRequest
Sourcefn eq(&self, other: &ProvideSignatureHelpRequest) -> bool
fn eq(&self, other: &ProvideSignatureHelpRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for ProvideSignatureHelpRequest
impl StructuralPartialEq for ProvideSignatureHelpRequest