pub struct ResizeTerminalRequest {
pub terminal_id: u32,
pub cols: u32,
pub rows: u32,
}Expand description
Request to resize a terminal.
Fields
terminal_id: u32cols: u32rows: u32Trait Implementations
Sourceimpl Clone for ResizeTerminalRequest
impl Clone for ResizeTerminalRequest
Sourcefn clone(&self) -> ResizeTerminalRequest
fn clone(&self) -> ResizeTerminalRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ResizeTerminalRequest
impl Debug for ResizeTerminalRequest
Sourceimpl Default for ResizeTerminalRequest
impl Default for ResizeTerminalRequest
Sourceimpl Hash for ResizeTerminalRequest
impl Hash for ResizeTerminalRequest
Sourceimpl Message for ResizeTerminalRequest
impl Message for ResizeTerminalRequest
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for ResizeTerminalRequest
impl PartialEq for ResizeTerminalRequest
Sourcefn eq(&self, other: &ResizeTerminalRequest) -> bool
fn eq(&self, other: &ResizeTerminalRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for ResizeTerminalRequest
impl Eq for ResizeTerminalRequest
impl StructuralPartialEq for ResizeTerminalRequest