pub struct ShowInputBoxRequest {
pub prompt: String,
pub value: String,
pub placeholder: String,
pub title: String,
pub password: bool,
}Expand description
Request to show an input box.
Fields
prompt: Stringvalue: Stringplaceholder: Stringtitle: Stringpassword: boolTrait Implementations
Sourceimpl Clone for ShowInputBoxRequest
impl Clone for ShowInputBoxRequest
Sourcefn clone(&self) -> ShowInputBoxRequest
fn clone(&self) -> ShowInputBoxRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ShowInputBoxRequest
impl Debug for ShowInputBoxRequest
Sourceimpl Default for ShowInputBoxRequest
impl Default for ShowInputBoxRequest
Sourceimpl Hash for ShowInputBoxRequest
impl Hash for ShowInputBoxRequest
Sourceimpl Message for ShowInputBoxRequest
impl Message for ShowInputBoxRequest
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for ShowInputBoxRequest
impl PartialEq for ShowInputBoxRequest
Sourcefn eq(&self, other: &ShowInputBoxRequest) -> bool
fn eq(&self, other: &ShowInputBoxRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for ShowInputBoxRequest
impl StructuralPartialEq for ShowInputBoxRequest